==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_cce_compliant_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCceCompliantResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'cce_info_list': 'list[CceInfo]'
    }

    attribute_map = {
        'count': 'count',
        'cce_info_list': 'cce_info_list'
    }

    def __init__(self, count=None, cce_info_list=None):
        """ListCceCompliantResponse

        The model defined in huaweicloud sdk

        :param count: 总数
        :type count: int
        :param cce_info_list: CCE信息列表
        :type cce_info_list: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        
        super(ListCceCompliantResponse, self).__init__()

        self._count = None
        self._cce_info_list = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if cce_info_list is not None:
            self.cce_info_list = cce_info_list

    @property
    def count(self):
        """Gets the count of this ListCceCompliantResponse.

        总数

        :return: The count of this ListCceCompliantResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListCceCompliantResponse.

        总数

        :param count: The count of this ListCceCompliantResponse.
        :type count: int
        """
        self._count = count

    @property
    def cce_info_list(self):
        """Gets the cce_info_list of this ListCceCompliantResponse.

        CCE信息列表

        :return: The cce_info_list of this ListCceCompliantResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        return self._cce_info_list

    @cce_info_list.setter
    def cce_info_list(self, cce_info_list):
        """Sets the cce_info_list of this ListCceCompliantResponse.

        CCE信息列表

        :param cce_info_list: The cce_info_list of this ListCceCompliantResponse.
        :type cce_info_list: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        self._cce_info_list = cce_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCceCompliantResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_cce_compliant_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCceCompliantResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'cce_info_list': 'list[CceInfo]'
    }

    attribute_map = {
        'count': 'count',
        'cce_info_list': 'cce_info_list'
    }

    def __init__(self, count=None, cce_info_list=None):
        r"""ListCceCompliantResponse

        The model defined in huaweicloud sdk

        :param count: 总数
        :type count: int
        :param cce_info_list: CCE信息列表
        :type cce_info_list: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        
        super(ListCceCompliantResponse, self).__init__()

        self._count = None
        self._cce_info_list = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if cce_info_list is not None:
            self.cce_info_list = cce_info_list

    @property
    def count(self):
        r"""Gets the count of this ListCceCompliantResponse.

        总数

        :return: The count of this ListCceCompliantResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListCceCompliantResponse.

        总数

        :param count: The count of this ListCceCompliantResponse.
        :type count: int
        """
        self._count = count

    @property
    def cce_info_list(self):
        r"""Gets the cce_info_list of this ListCceCompliantResponse.

        CCE信息列表

        :return: The cce_info_list of this ListCceCompliantResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        return self._cce_info_list

    @cce_info_list.setter
    def cce_info_list(self, cce_info_list):
        r"""Sets the cce_info_list of this ListCceCompliantResponse.

        CCE信息列表

        :param cce_info_list: The cce_info_list of this ListCceCompliantResponse.
        :type cce_info_list: list[:class:`huaweicloudsdkcoc.v1.CceInfo`]
        """
        self._cce_info_list = cce_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCceCompliantResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
